#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.mikegtn.net/1117
# source           : http://www.mikegtn.net/packages/inkblot/inkblot-0.99.9.tar.gz

# Package name
NAME="inkblot"
# Package version
VERSION="0.99.9"
# Source code URL
SOURCE="http://www.mikegtn.net/packages/inkblot/inkblot-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README TODO"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --sysconfdir=/etc"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="60.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: inkblot reports on the remaining ink levels of connected printers
$NAME:
$NAME: Inkblot reports on the remaining ink levels in a wide variety of USB
$NAME: and Parallel connected printers. Inkblot provides an ink status
$NAME: notification, and can provide a more detailed dialog showing the
$NAME: level of ink remaining to your printer. Inkblot uses libinklevel to
$NAME: detect your printer on first run. Where available, the status of
$NAME: individual colour ink reservoirs is shown. Inkblot lives in the
$NAME: notification area, and uses session management to ensure it remains
$NAME: available once added to your setup.
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xf $NAME-$VERSION.tar.gz

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make

# Install on temporary directory
make install DESTDIR=$PKG
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
mv $PKG/usr/share/pixmaps/inkblot.png $PKG/usr/share/icons/hicolor/48x48/apps
rmdir $PKG/usr/share/pixmaps

# Fix .desktop file
sed -i -e 's/.png//' $PKG/usr/share/applications/inkblot.desktop

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
